@@ -16,8 +16,15 @@ def trace_handler(fn, start=False):
     def handler(func):
         @wraps(func)
         def wrapper(*args, **kwargs):
-            if not start and not TraceContextManager.getLocalContext():
+            ctx = TraceContextManager.getLocalContext()
+            if not start and not ctx:
                 return fn(*args, **kwargs)
+            
+            # check raise step error
+            if ctx and ctx.error_step:
+                end_interceptor()
+                raise Exception(ctx.error_step)
+            
             try:
                 callback = func(*args, **kwargs)
             except Exception as e:
@@ -111,27 +118,29 @@ def interceptor(rn_environ, *args, **kwargs):
     
     callback = fn(*args, **kwargs)
     
-    if getattr(callback, 'status_code', None):
-        status_code = callback.status_code
-        errors = [callback.reason_phrase, callback.__class__.__name__]
-        interceptor_error(status_code, errors)
-    
-    if conf.profile_http_header_enabled:
-        keys = []
-        for key, value in environ.items():
-            if key.startswith('HTTP_'):
-                keys.append(key)
-        keys.sort()
+    ctx = TraceContextManager.getLocalContext()
+    if ctx:
+        if getattr(callback, 'status_code', None):
+            status_code = callback.status_code
+            errors = [callback.reason_phrase, callback.__class__.__name__]
+            interceptor_error(status_code, errors)
         
-        text = ''
-        for key in keys:
-            text += '{}={}\n'.format(key.split('HTTP_')[1].lower(), environ[key])
-
-        datas = [' ', 'HTTP-HEADERS', text]
-        ctx.start_time = DateUtil.nowSystem()
-        UdpSession.send_packet(PacketTypeEnum.PACKET_MSG, ctx, datas)
-
-    end_interceptor()
+        if conf.profile_http_header_enabled:
+            keys = []
+            for key, value in environ.items():
+                if key.startswith('HTTP_'):
+                    keys.append(key)
+            keys.sort()
+            
+            text = ''
+            for key in keys:
+                text += '{}={}\n'.format(key.split('HTTP_')[1].lower(), environ[key])
+    
+            datas = [' ', 'HTTP-HEADERS', text]
+            ctx.start_time = DateUtil.nowSystem()
+            UdpSession.send_packet(PacketTypeEnum.PACKET_MSG, ctx, datas)
+    
+        end_interceptor()
     return callback
 
 
@@ -198,12 +207,15 @@ def interceptor_db_execute(fn, *args, **kwargs):
     ctx.start_time = start_time
     ctx.active_sqlhash = query
     
-    errors = []
-    
     try:
         callback = fn(*args, **kwargs)
         return callback
     except Exception as e:
+        ctx.error_step = e
+        if not ctx.error:
+            ctx.error = 1
+            
+        errors = []
         errors.append(e.__class__.__name__)
         errors.append(e.args[1] if len(e.args) > 1 else \
                           e.args[0])
@@ -213,9 +225,6 @@ def interceptor_db_execute(fn, *args, **kwargs):
             errors.append('')
         UdpSession.send_packet(PacketTypeEnum.PACKET_ERROR, ctx, errors)
         
-        if not ctx.error:
-            ctx.error = 1
-    
     finally:
         datas = [ctx.lctx.get('dbc', ''), query]
         ctx.elapsed = DateUtil.nowSystem() - start_time
