@@ -36,9 +36,10 @@ def instrument_revproxy_views(module):
                 callback = fn(*args, **kwargs)
                 return callback
             except Exception as e:
-                from whatap import logging
-                logging.debug(e, extra={'id': 'WA856'}, exc_info=True)
-
+                ctx.error_step = e
+                if not ctx.error:
+                    ctx.error = 1
+                    
                 errors = []
                 errors.append(e.__class__.__name__)
                 errors.append(str(e.args[0]))
@@ -48,8 +49,6 @@ def instrument_revproxy_views(module):
                     errors.append('')
                 UdpSession.send_packet(PacketTypeEnum.PACKET_ERROR, ctx, errors)
 
-                if not ctx.error:
-                    ctx.error = 1
             finally:
                 datas = [ctx.httpc_url, ctx.mcallee]
                 ctx.elapsed = DateUtil.nowSystem() - start_time
